########
 setux
########

**Setup Tux**

========
Abstract
========

Install, Deploy, Admin

=====
Usage
=====

.. code-block:: shell

    setux


============
Installation
============

.. code-block:: shell 

    $ pip install setux
